<?php 
/*
 *  $Id$
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many individuals
 * and is licensed under the LGPL. For more information, see
 * <http://www.doctrine-project.org>.
 */

namespace Doctrine\ORM;

/**
 * Represents a native SQL query.
 *
 * @author Roman Borschel <roman@code-factory.org>
 * @since 2.0
 */
final class NativeQuery extends AbstractQuery
{
    private $_sql;

    /**
     * Initializes a new instance of the <tt>NativeQuery</tt> class that is bound
     * to the given EntityManager.
     *
     * @param EntityManager $em The EntityManager to use.
     */
    public function __construct(EntityManager $em)
    {
        parent::__construct($em);
    }

    /**
     * Sets the SQL of the query.
     *
     * @param string $sql
     * @return Doctrine\ORM\AbstractQuery
     */
    public function setSql($sql)
    {
        $this->_sql = $sql;
        return $this;
    }

    /**
     * Gets the SQL query.
     *
     * @return mixed The built SQL query or an array of all SQL queries.
     * @override
     */
    public function getSql()
    {
        return $this->_sql;
    }

    /**
     * Executes the query.
     *
     * @param array $params
     * @return Statement The Statement handle.
     * @override
     */
    protected function _doExecute(array $params)
    {
        return $this->_em->getConnection()->execute($this->_sql, $this->_prepareParams($params));
    }
    
    /**
     * {@inheritdoc}
     * 
     * @override
     */
    protected function _prepareParams(array $params)
    {
        $sqlParams = array();
        
        foreach ($params as $key => $value) {
            $sqlParams[$key] = $value;
        }
        ksort($sqlParams);
        
        return array_values($sqlParams);
    }
}